const app = getApp()

import Dialog from '@vant/weapp/dialog/dialog';
import Notify from '@vant/weapp/notify/notify';

import {
  selfFormatTimeYMD,
  selfFormatTimeHM
} from "../../../../utils/util.js"

import {
  selectReservationListByUserIdRq,
  selectVisitorInvitationRecordRq,
  cancelOrderRq
} from "../../../../api/meeting/meetingRoom.js"

Page({

  /**
   * 页面的初始数据
   */
  data: {
    IMG_NAME: app.IMG_NAME,
    userData: null,
    dataChange: false,
    tabTitle: '预约记录',
    // 预约记录参数
    reservationPageNum: 1,
    reservationPageSize: 10,
    reservationDataList: [],
    reservationIsDataAll: false,
    search: {
      title: {
        text: '会议名称',
        value: ''
      },
      status: {
        value: 1,
        option: [{
            text: '全部预约',
            value: ''
          },
          {
            text: '待审核',
            value: 1
          },
          {
            text: '待开始',
            value: 2
          },
          {
            text: '已结束',
            value: 3
          },
          {
            text: '已取消',
            value: 4
          },
          {
            text: '已驳回',
            value: 5
          },
        ]
      }
    },
    showRejectReason: false, // 是否展示弹出层
    rejectlId: '', // 驳回预约会议id
    rejectReason: '', // 驳回预约原因
    beforeReject(action) {
      return new Promise(resolve => {
        if (action === 'confirm') {
          resolve(false)
        } else {
          resolve(true)
        }
      });
    }, // 弹出层点击确认不关闭，手动关
    // 会议重新预约需要参数
    editId: '',
    showEdit: false,
    editAction: [{
        name: '重新选择时间、会议室',
        type: 1
      },
      {
        name: '重新编辑会议信息',
        type: 2
      },
    ],
    timeShow: false,
    currentDate: new Date().getTime(),
    minDate: new Date().getTime(),
    maxDate: '',
    formatter(type, value) {
      if (type === 'year') {
        return `${value}年`;
      }
      if (type === 'month') {
        return `${value}月`;
      }
      if (type === 'day') {
        return `${value}日`;
      }
      return value;
    },
    // 参与记录参数，不需要
    // participatePageNum: 1,
    // participatePageSize: 10,
    // participateDataList: [],
    // participateIsDataAll: false,
  },
  changeSearchTitle(e) {
    this.setData({
      ['search.title.value']: e.detail,
    })
  },
  searchTitle() {
    // 刷新预约数据
    this.setData({
      reservationPageNum: 1,
      reservationDataList: [],
      reservationIsDataAll: false,
    })
    this.getDataList()
    this.selectComponent('#item').toggle()
  },
  changeSearchStatus(e) {
    // 刷新预约数据
    this.setData({
      reservationPageNum: 1,
      reservationDataList: [],
      reservationIsDataAll: false,
      ['search.status.value']: e.detail
    })
    this.getDataList()
  },
  /**
   * 生命周期函数--监听页面加载
   */
  onLoad(options) {
    let _this = this;
    _this.setData({
      userData: wx.getStorageSync('user'),
    })
    // 获取数据
    let userId = _this.data.userData.id
    // 获取预约数据
    _this.getReservationData({
      userId,
      pageNum: _this.data.reservationPageNum,
      pageSize: _this.data.reservationPageSize,
    })
    // 获取一月后时间，默认只能选一个月之后
    const today = new Date()
    const newDate = new Date(today)
    newDate.setMonth(newDate.getMonth() + 1)
    _this.setData({
      maxDate: newDate.getTime()
    })
  },

  // 获取数据
  getDataList() {
    // 获取参数
    let _this = this;
    let tabTitle = _this.data.tabTitle
    let userId = _this.data.userData.id
    let isDataAll = null
    let pageNum = null
    let pageSize = null
    // 预约记录参数，目前只保留预约记录，其余去掉
    isDataAll = _this.data.reservationIsDataAll
    pageNum = _this.data.reservationPageNum
    pageSize = _this.data.reservationPageSize

    // 判断数据是否已全部加载
    if (isDataAll) {
      return;
    }
    // 传递参数
    let param = {
      userId,
      pageNum,
      pageSize
    }
    _this.getReservationData(param)
  },

  // 获取预约数据
  getReservationData(param) {
    let _this = this;
    let {
      pageNum,
      pageSize,
      userId
    } = param
    // 查询数据
    selectReservationListByUserIdRq({
      pageNum,
      pageSize,
      userId,
      parkId: 25,
      title: _this.data.search.title.value,
      statusValue: _this.data.search.status.value
    }).then(res => {
      console.log('selectReservationListByUserIdRq', res);
      // 判断数据是否全部查询
      let queryDataList = res.page.records;
      if (queryDataList && queryDataList.length > 0) {
        // 更新参数
        let reservationDataList = _this.data.reservationDataList.concat(_this.formartData(queryDataList));
        let reservationPageNum = _this.data.reservationPageNum + 1;
        _this.setData({
          reservationPageNum,
          reservationDataList,
        })
      } else {
        _this.setData({
          reservationIsDataAll: true
        })
      }
    })
  },

  // 获取参与数据，此处不需要
  getParticipateData(param) {
    let _this = this;
    let {
      pageNum,
      pageSize,
      userId
    } = param
    // 查询数据
    selectVisitorInvitationRecordRq({
      pageNum,
      pageSize,
      userId
    }).then(res => {
      console.log('selectVisitorInvitationRecordRq', res);
      // 判断数据是否全部查询
      let queryDataList = res.page.records;
      if (queryDataList && queryDataList.length > 0) {
        // 更新参数
        let participateDataList = _this.data.participateDataList.concat(_this.formartData(queryDataList));
        let participatePageNum = _this.data.participatePageNum + 1;
        _this.setData({
          participatePageNum,
          participateDataList,
        })
      } else {
        _this.setData({
          participateIsDataAll: true
        })
      }
    })
  },

  // 格式化数据
  formartData(queryDataList) {
    // 格式化数据
    return queryDataList.map(item => {
      item.timeSlot = selfFormatTimeYMD(item.startTime) + ' ' + selfFormatTimeHM(item.startTime) + '~' + selfFormatTimeHM(item.endDate);
      // 状态字体颜色
      let statusColor = "#FFB119";
      // 按钮是否显示
      let statusValue = item.statusValue;
      let showPay = false;
      let showInvite = false;
      let showCancel = false;
      let showDetail = false;
      // 待支付 0 ：去支付、取消订单、查看详情
      if (statusValue == 0) {
        showPay = true;
        showCancel = true;
        showDetail = true;
        // 状态字体颜色
        statusColor = "#FFB119";
      }
      // 待使用 1：去邀请、取消订单、查看详情
      if (statusValue == 1) {
        showInvite = true;
        showCancel = true;
        showDetail = true;
        // 状态字体颜色
        statusColor = "#3794FF";
        // 待使用 修改为 预约成功
        item.statusName = '预约成功'
      }
      // 进行中 2：去邀请、查看详情
      if (statusValue == 2) {
        showInvite = true;
        showDetail = true;
        // 状态字体颜色
        statusColor = "#FF4040";
      }
      // 已结束 3：查看详情
      if (statusValue == 3) {
        showDetail = true;
        // 状态字体颜色
        statusColor = "#333333";
      }
      // 已取消 4：查看详情
      if (statusValue == 4) {
        showDetail = true;
        // 状态字体颜色
        statusColor = "#7F7F7F";
      }
      //
      // 赋值
      item.showPay = showPay;
      item.showInvite = showInvite;
      item.showCancel = showCancel;
      item.showDetail = showDetail;
      // 状态字体颜色
      item.statusColor = statusColor;
      // 图片
      if (item.roomContent.indoorPicUrl) {
        try {
          item.roomContent.indoorPicUrlFirst = JSON.parse(item.roomContent.indoorPicUrl)[0].url
        } catch (error) {
          console.log(`JSON error : ${error}`);
        }
      }
      return item;
    })

  },

  // 跳转-预约详情
  jumpMeetingDetail(e) {
    console.log('jumpMeetingDetail', e);
    let id = e.currentTarget.dataset.id
    wx.navigateTo({
      url: "/pages/meeting/reservationRecord/meetingRecord/meetingDetail/meetingDetail?act=approve&id=" + id,
    })
  },
  /**
   * 跳转会务负责人页面，选择会务负责人
   * @param {}} e 
   */
  goStaff(e) {
    let id = e.currentTarget.dataset.id
    wx.navigateTo({
      url: "/pages/meeting/meetingRoom/meetingStaff/meetingStaff?rId=" + id,
    })
  },
  // 取消预约一系列方法
  cancelConfirm(e) {
    console.log('cancelConfirm', e);
    let _this = this;
    let id = e.currentTarget.dataset.id
    _this.setData({
      cancelId: id,
      showCancelReason: true,
      cancelReason: ''
    })
  },
  onCloseCancel(e) {
    let _this = this;
    _this.setData({
      cancelId: '',
      showCancelReason: false,
      cancelReason: ''
    })
  },
  onChangeCancelReason(e) {
    let _this = this;
    _this.setData({
      cancelReason: e.detail
    })
  },
  // 取消订单
  cancelOrder() {
    let _this = this;
    let id = _this.data.cancelId
    let reason = _this.data.cancelReason
    if (id === '') {
      return
    }
    if (reason === '') {
      Notify('请输入取消原因！')
      return
    }
    cancelOrderRq({
      id: id,
      cancelResaon: reason
    }).then(res => {
      console.log('cancelOrderRq', res);
      if (res.code == 0) {
        // 刷新预约数据
        _this.setData({
          reservationPageNum: 1,
          reservationDataList: [],
          reservationIsDataAll: false,
          showCancelReason: false
        })
        _this.getDataList()
      } else {
        // 危险通知
        Notify({
          type: 'danger',
          message: res.msg
        });
      }
    })
  },
  editConfirm(e) {
    let id = e.currentTarget.dataset.id
    this.setData({
      editId: id,
      showEdit: true
    })
  },
  hideEdit() {
    this.setData({
      showEdit: false
    })
  },
  editMode(e) {
    let _this = this
    if (e.detail.type === 1) {
      // 重选时间会议室
      this.setData({
        showEdit: false,
        timeShow: true
      })
    } else {
      // 直接跳转
      console.log('重新编辑会议基本信息！')
      this.setData({
        showEdit: false,
      })
      wx.navigateTo({
        url: "/pages/meeting/meetingRoom/meetingOrder/meetingOrder?rId=" + _this.data.editId,
      })
    }
  },
  showTimePicker() {
    this.setData({
      timeShow: true
    });
  },
  hideTimePicker() {
    this.setData({
      timeShow: false
    });
  },
  // 跳转会议预约页面
  goRes(e) {
    let _this = this
    // 加入rId参数，为预约id，用于重新修改
    wx.navigateTo({
      url: '/pages/meeting/meetingReservation/meetingReservation?rId=' + _this.data.editId + '&time=' + e.detail,
    })
  },
  pass() {
    Dialog.confirm({
        title: '确认',
        message: '是否确认通过会议室申请？',
      })
      .then(() => {
        // on confirm
        console.log('已通过')
        // 重新加载数据
        this.getDataList()
      })
      .catch(() => {
        // on cancel
      });
  },
  // 驳回预约
  rejectConfirm(e) {
    console.log('rejectConfirm', e);
    let _this = this;
    let id = e.currentTarget.dataset.id
    _this.setData({
      rejectId: id,
      showRejectReason: true,
      rejectReason: ''
    })
  },
  onCloseReject(e) {
    let _this = this;
    _this.setData({
      rejectId: '',
      showRejectReason: false,
      rejectReason: ''
    })
  },
  onChangeRejectReason(e) {
    let _this = this;
    _this.setData({
      rejectReason: e.detail
    })
  },
  // 取消订单
  rejectOrder() {
    let _this = this;
    let id = _this.data.rejectId
    let reason = _this.data.rejectReason
    if (id === '') {
      return
    }
    if (reason === '') {
      Notify('请输入驳回原因！')
      return
    }
    // 执行驳回方法
    console.log('驳回，原因为' + reason)
    return
    cancelOrderRq({
      id: id,
      cancelResaon: reason
    }).then(res => {
      console.log('rejectOrder', res);
      if (res.code == 0) {
        // 刷新预约数据
        _this.setData({
          reservationPageNum: 1,
          reservationDataList: [],
          reservationIsDataAll: false,
          showRejcctReason: false
        })
        _this.getDataList()
      } else {
        // 危险通知
        Notify({
          type: 'danger',
          message: res.msg
        });
      }
    })
  },
  /**
   * 生命周期函数--监听页面初次渲染完成
   */
  onReady() {

  },

  /**
   * 生命周期函数--监听页面显示
   */
  onShow() {
    let _this = this;
    // 数据是否变化
    if (_this.data.dataChange) {
      // 刷新数据
      _this.setData({
        dataChange: false,
        // 预约记录参数
        reservationPageNum: 1,
        reservationDataList: [],
        reservationIsDataAll: false,
        // 搜索重置
        ['search.title.value']: '',
        ['search.status.value']: 0
      })

      // 获取数据
      let userId = _this.data.userData.id
      // 获取预约数据
      _this.getReservationData({
        userId,
        pageNum: _this.data.reservationPageNum,
        pageSize: _this.data.reservationPageSize,
      })
    }
  },

  /**
   * 生命周期函数--监听页面隐藏
   */
  onHide() {

  },

  /**
   * 生命周期函数--监听页面卸载
   */
  onUnload() {

  },

  /**
   * 页面相关事件处理函数--监听用户下拉动作
   */
  onPullDownRefresh() {
    console.log('onPullDownRefresh', '页面相关事件处理函数--监听用户下拉动作');
  },

  /**
   * 页面上拉触底事件的处理函数
   */
  onReachBottom() {
    console.log('onReachBottom', '页面上拉触底事件的处理函数');
    let _this = this;
    // 获取数据
    _this.getDataList()
  },

  /**
   * 用户点击右上角分享
   */
  onShareAppMessage(e) {
    console.log('onShareAppMessage', e);
    let _this = this;
    let id = e.target.dataset.id;
    let detail = _this.data.reservationDataList.find(item => item.id == id)
    //
    let param = {
      title: detail.title,
      path: "/pages/meeting/invite/invite?id=" + id,
      imageUrl: app.IMG_NAME + detail.roomContent.indoorPicUrlFirst,
    }
    console.log('onShareAppMessage', param);
    return param;
  }
})